Calculates DysPIA statistics for a given query gene pair set.
calcDyspiaStat(
stats,
selectedStats,
DyspiaParam = 1,
returnAllExtremes = FALSE,
returnLeadingEdge = FALSE
)Named numeric vector with gene pair-level statistics sorted in decreasing order (order is not checked).
Indexes of selected gene pairs in the `stats` array.
DysPIA weight parameter (0 is unweighted, suggested value is 1).
If TRUE return not only the most extreme point, but all of them. Can be used for enrichment plot.
If TRUE return also leading edge gene pairs.
Value of DysPIA statistic if both returnAllExtremes and returnLeadingEdge are FALSE. Otherwise returns list with the folowing elements:
res -- value of DysPIA statistic
tops -- vector of top peak values of cumulative enrichment statistic for each gene pair;
bottoms -- vector of bottom peak values of cumulative enrichment statistic for each gene pair;
leadingEdge -- vector with indexes of leading edge gene pairs that drive the enrichment.