Learn R Programming

DysPIA (version 1.3)

calcDyspiaStatCumulative: Calculates DysPIA statistic values for all the prefixes of a gene pair set

Description

Calculates DysPIA statistic values for all the prefixes of a gene pair set

Usage

calcDyspiaStatCumulative(stats, selectedStats, DyspiaParam)

Arguments

stats

Named numeric vector with gene pair-level statistics sorted in decreasing order (order is not checked)

selectedStats

indexes of selected gene pairs in a `stats` array

DyspiaParam

DysPIA weight parameter (0 is unweighted, suggested value is 1)

Value

Numeric vector of DysPIA statistics for all prefixes of selectedStats.